module Medidata::API
  require_relative "type"

  # A Download is available when an invoice has been sent to the insurance company,
  # but the content check does not go through there and an invoice response
  # (General Invoice Response) is returned.
  # These invoice responses then arrive on the MD client and have to be downloaded
  # and confirmed by the customer's Denteo application using ela / downloads.
  class Download < Dry::Struct
    # Reference to the document. This is generated by the MediData client.
    attribute :transmissionReference, Types::Strict::String
    # Reference to the document
    attribute :documentReference, Types::Strict::String
    # Reference to the business case
    attribute :correlationReference, Types::Strict::String
    # Sender identification
    attribute :senderGln, Types::Strict::String
    # MIME document type
    attribute :docType, Types::Strict::String
    # Length of the document in bytes
    attribute :fileSize, Types::Strict::Integer
    # TEST or PRODUCTION
    attribute :mode, Types::Strict::String
    # Document status
    attribute :status, Types::Strict::String
    # Date document was delivered
    attribute :created, Types::JSON::DateTime
  end
end