module Medidata::API
  require_relative "type"

  # A Notification is generated when an upload results in the status «ERROR»,
  # e.g. the schema check on the MD client detects an error.
  #
  # The status ERROR indicates that there was an error during the transmission
  # and the recipient did not receive the file.
  # In the associated notification of this ERROR, the customer receives more
  # detailed information on the error code, cause and possible remedial measures.
  class Notification < Dry::Struct
    # ID is a unique identifier for notification
    attribute :id, Types::Strict::Integer.optional
    # Subject of the notification (in three languages)
    attribute :subject, Types::Strict::Hash
    # The content of the notification (in three languages)
    attribute :message, Types::Strict::Hash
    # The notification type.
    attribute :type, Types::Strict::String.optional.default("".freeze)
    # “true” if the notification has already been marked as red, otherwise “false”.
    attribute :read, Types::Strict::Bool.default(false)
    # The notification’s creation date ISO 8601 timestamp
    attribute :created, Types::JSON::DateTime
    # The template’s name
    attribute :template, Types::Strict::String
    # The notification’s mode
    attribute :mode, Types::Strict::String
    # The error code
    attribute :errorCode, Types::Strict::String
    # Possible causes (in three languages). Texts are entered by MediData
    attribute :potentialReasons, Types::Strict::Hash
    # Possible solutionss (in three languages). Texts are entered by MediData
    attribute :possibleSolutions, Types::Strict::Hash
    # Additional parameters for notification
    attribute :notificationParameters, Types::Strict::Hash
    # Additional technical information. (can be used for problem analysis.
    attribute :technicalInformation, Types::Strict::String.optional.default(nil)
  end
end