module Medidata::API
  require_relative "type"

  class Participant < Dry::Struct
    # Recipient’s GLN number.
    # Note: Always the same GLN as with the parameter “glnReceiver”.
    attribute :glnParticipant, Types::Strict::String
    # Recipient’s GLN number
    attribute :glnReceiver, Types::Strict::String
    # Name of the participant
    attribute :name, Types::Strict::String
    # Address (street name + house number)
    attribute :street, Types::Strict::String
    # Post code
    attribute :zipCode, Types::Strict::String
    # Name of city
    attribute :town, Types::Strict::String
    # List of laws supported by the participants
    attribute :lawTypes, Types::Strict::Array
    # Number registered with the Swiss Federal Office of Public Health (FOPH)
    attribute :bagNumber, Types::Strict::Integer.optional
    # Is the change from TG to TP accepted by the participant. The default is false.
    attribute :tgTpChange, Types::Strict::Bool
    # The sending of a document to this participant may result in additional
    # costs (e.g. printing costs) if additionalCosts is set to true. The default is false.
    attribute :additionalCosts, Types::Strict::Bool
    # Maximum document size that the participant can or wants to receive.
    attribute :maxReceive, Types::Strict::Integer
    # List of the document MIME types not supported by the participant.
    # No documents of this type may be sent to the recipient.
    attribute :notSupported, Types::Strict::Array
    # Specifies whether the participant can receive and process TG documents.
    attribute :tgAllowed, Types::Strict::Bool
  end

  class ParticipantsQuery
    attr_reader :lawType, :name, :glnParticipant

    def initialize(lawType: "", name: "", glnParticipant: "")
      @lawType = lawType
      @name = name
      @glnParticipant = glnParticipant
    end
  end

  # TODO: Add LawType type
end